Struct diem_management::secure_backend::SecureBackend [−][src]
SecureBackend is a parameter that is stored as set of semi-colon separated key/value pairs. The only expected key is backend which defines which of the SecureBackends the parameters refer to. Some backends require parameters others do not, so that requires a conversion into the config::SecureBackend type to parse.
Example: backend=vault;server=http://127.0.0.1:8080;token=/path/to/token
Fields
backend: Stringparameters: HashMap<String, String>Trait Implementations